#!/usr/bin/php
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2005 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Frederic Wenzel <fred@osuosl.org>                           |
// |            Josh Schonstal <schonstal@osuosl.org>                       |
// +------------------------------------------------------------------------+
// $Id$

/**
  * Cron.php is the script that runs all of Maintain's cron modules
  * The crontab entry should be * * * * * /path/to/maintain/bin/cron.php [options]
  *
  * @author $Author$
  * @filesource
  * @package    bin
  */

// start with a reference point for maintain constant inclusion
require_once(dirname(__FILE__).'/../includes.php');
require_once(MODDIR.'/module.php');
require_once('PEAR.php');   // for error handling

// parse arguments passed on the command line
// and put them into an array called 'mode'
$mode = array(
    'production' => FALSE,
    'build_only' => FALSE,
    'force_update' => FALSE,
    'debug' => FALSE,
    'force_run' => FALSE,
    'no_backend' => FALSE,
    'backend_only' => FALSE
);
foreach ($argv as $no => $arg) {
    switch ($arg) {
    
    case '-h':
    case '--help':
        usage();
        break;

    case '-p':
    case '--production':
        $mode['production'] = TRUE;
        break;

    case '-b':
    case '--build-only':
        $mode['build_only'] = TRUE;
        break;

    case '-f':
    case '--force-update':
        $mode['force_update'] = TRUE;
        break;

    case '-d':
    case '--debug':
        $mode['debug'] = TRUE;
        break;

    case '-r':
    case '--force-run':
        $mode['force_run'] = TRUE;
        break;

    case '-n':
    case '--no-backend':
        $mode['no_backend'] = TRUE;
        break;

    case '-o':
    case '--backend-only':
        $mode['backend_only'] = TRUE;
        break;
        
    default:
        if ($no == 0) break;    // first argument is always the file name
        print("cron.php: unrecognized option: `".$arg."'.\nTry `".$argv[0]." --help' for more information.\n");
        exit(1);
        
    }
}

// if no mode was selected at all, exit now with usage information.
if (!in_array(TRUE, $mode)) usage();
if ($mode['no_backend'] && $mode['backend_only']) usage();

if(!$mode['backend_only']) {
    Module::do_cron('cron_mod', $mode['force_run']);
}

if(!$mode['no_backend'])
    Module::do_cron('backend', $mode['force_run'], $mode);

exit(0);
// ----------------------------------------------------------------------------
// functions

// {{{ usage()
/**
 * This method explains usage of the "cron.php" script.
 * @return void
 */
function usage() 
{
    $v = VERSION;   // constants don't work in heredoc syntax:
    
    print <<<EOT
Maintain {$v} - Cron Module Run Script

Usage: cron.php --production [--backend-only] [--no-backend] [--force-update] [--help] [--force-run]
Build config files and push to servers accordingly.

 --production, -p      Build everything and push to the production hosts.  This
                       will run all the cron modules at the appropriate times.
 --force-update, -f    Build everything and push to the production hosts even
                       if there isn't a diff in any of the configuration files.
 --force-run, -r       Run all cron modules, regardless of the start time or
                       interval.  It is STRONGLY recommended that you do not 
                       set this flag in your crontab.
 --backend-only, -o    Only execute cron modules hooked into the backend hook.
                       You cannot have -o and -n set at the same time.
 --no-backend, -n      Only execute modules that are not hooked into the backend
                       hook.  You cannot have -o and -n set at the same time.
 --help, -h            This help message.

EOT;

    exit(1);
}
// }}}
?>
