<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/trunk/class/dao/extended/ns.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |       
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Daniel Robert <robert@osuosl.org>                           |
// |            Josh Schonstal <schonstal@osuosl.org>                       |
// +------------------------------------------------------------------------+
// $Id: ns.php 4841 2006-09-28 20:43:20Z schonstal $

/**
  * ns.php - contains the {@link NS} class
  *
  * @author $Author: schonstal $
  * @filesource
  * @package    classes
  * @subpackage dao
  */

include_once DAODIR.'/Nameserver.php';

/**
  * A nameserver object
  *
  * @package    classes
  * @subpackage dao
  */
class NS extends DAO_Nameserver {

    // {{{ constructor

    /**
      * Constructor
      *
      * @param  int Nameserver ID (primary key)
      */
	function NS ( $ns_id = 0 ) 
    {
        if ($ns_id) {
            $this->id = $ns_id;
            $this->get($this->id);
        }
    }
    // }}}
    

/* Setters */
    // {{{ setGlue()

    /**
      * Set the glue for this nameserver
      *
      * @param  mixed   IP address (int or dotted quad)
      * @return boolean true on success
      */
    function setGlue($glu) 
    {
        $this->ipobj = new IP($glu);
        $this->glue = $this->ipobj->ip_int;
        return true;
    }

    // }}}
    // {{{ setName()
    function setName($name)
    {
        $this->name = $name;
    }
    // }}}
    // {{{ setDomain()
    function setDomain($domain)
    {
        $this->domain = $domain;
    }
    // }}}

/* Getters */
    // {{{ getGlue()
    function getGlue()
    {
        if($this->glue != 0)
            return long2ip($this->glue);
        else
            return "";
    }
    // }}}
    // {{{ getName()
    function getName()
    {
        return $this->name;
    }
    // }}}
    // {{{ getDomain()
    function getDomain()
    {
        return $this->domain;
    }
    // }}}


// validation
    // {{{ validateGlue()
    function validateGlue()
    {
        if($this->glue != 0 && $this->ipobj->origin == "other")
            return _("If a glue is specified, it must be a valid dotted quad (x.x.x.x)");

        return true;
    }
   // }}}

   // {{{ validateName()
   function validateName()
   {
        if (!preg_match("/^([[:alnum:]]([[:alnum:]\-]{0,61}[[:alnum:]])?\.)+[[:alnum:]]([[:alnum:]\-]{0,61}[[:alnum:]])?$/", $this->name))
            return "$this->name "._("is an invalid hostname");

        /* You can actually have multiple of the same name server
            for different domains or glues.
        $dbdo = DB_DataObject::Factory('nameserver');
        $dbdo->whereAdd();
        $dbdo->whereAdd("name LIKE '{$this->name}'");
        $dbdo->whereAdd("id!='{$this->id}'");
        
        if($dbdo->find())
            return "$this->name "._("is already in use by a nameserver.");
        */
        
        return true;
   }
   // }}}

}
?>
