<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Zack Bartel <bartel@osuosl.org>                             |
// |            Frederic Wenzel <fred@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: DomainCreateForm.php 3971 2005-12-15 23:09:25Z bartel $

/**
 *  DomainCreateForm.php - contains the {@link DomainCreateForm} class
 *
 *  @author $Author:$
 *  @package    htdocs  
 *  @subpackage forms
 *  @filesource
 */

require_once(FORMDIR."/MaintainForm.php");

/**
 *  This class is the form that is used to create a new Domain object
 *
 *  @package    htdocs
 *  @subpackage forms
 */ 
class DomainCreateForm extends MaintainForm
{

//{{{   vars

    /**
     *  This array maps form labels to DBDO vars and vice verse
     */
    var $map = array("Domain_Name"=>"name",
                    "Master_Domain_Name"=>"master_domain",
                    "Enabled"=>"enabled"/*,
                    "Comment"=>"comment"*/);

//}}}
//{{{   form_init_elements()

    /**
     *  This method is responsible for intializing the form elements that are going
     *  to be displayed and filled in by the user.
     */
    function form_init_elements() 
    {
        $name = new FEText(_("Domain Name"), true);
        $parent = new FEListBox(_("Master Domain Name"), false);
        $status = new FEListBox(_("Enabled"), false);
        //Later: $comment = new FETextArea(_("Comment"),true, 5, 40);
        
        $parent->set_list_data($this->_domains()); 
        $status->set_list_data(array("Enabled"=>1,
                                    "Disabled"=>0));

        $this->add_elements($name, $parent, $status);
    }

//}}}
//{{{   form_init_data()

    /**
     *  This method just sets the initial form values for certain fields.
     */
    function form_init_data()
    {
        return;
    }

//}}}
//{{{   form_backend_validation()

    /**
     *  This method validares the form values to see if they are suitable to be
     *  used in the form action.
     *
     *  @return Boolean     True if the data is valid
     */
    function form_backend_validation()
    {
        $res = true;
        
        $vals = $this->get_all_element_values();
        
        $d = new Domain($_REQUEST['id']);
        $d->setFrom($this->remap($vals,DBDO));
        

        $valid = $d->validate();

        if($valid !== true) {
            $errors = $this->remap($valid, FORM);
            $res = false;
            foreach($errors as $label=>$error) {
                if($error !== true)
                    $this->add_error($label, $error);
            }
        }

        return $res;
    }

//}}}
//{{{   form_action()

    function form_action()
    {
        global $user;
        
        $result = true;        

        switch(strtolower($this->get_action())) {

        case 'submit':
            $vals = $this->get_all_element_values();
        
            $domain = new Domain();
            $domain->query("BEGIN");

            $domain->setFrom($this->remap($vals, DBDO));

            /* If there is a master domain selected then make the name */
            if ($vals[_("Master_Domain_Name")] != 0)    {
                /* There's probably a better way to do this */
                $domain->name .= ".".$domain->getMaster_domain();
            }

            $v = $domain->validate();
            if ($v !== true)    {
                $domain->query("ROLLBACK");
                $this->add_error(_("ERROR"), $v);
                return false;
            }
            
            if(!$domain->insert()) {
                $domain->query("ROLLBACK");
                $result = false;
                $this->add_error(_("ERROR"),_("Couldn't add Domain to database"));
            } else {
                $domain->query("COMMIT");
                $domain->write_history($vals[_("Comment")], ACTION_CREATE,$user->username);
                $result = true;
            }

            /* Add to current zone */
            $zd = DB_DataObject::Factory('zone_domain');
            $zd->zone = $_SESSION['zone'];
            $zd->domain = $domain->id;
            $zd->insert();

            break;

        default:
            die_hard(_("Invalid form action"));
            break;
        }
        return $result;
    }

//}}}
//{{{   form_success()

    function form_success()
    {
        $div = html_div("msuccess");
        $indlink = html_a(web_root()."index.php", _("[Return to Index]"));
        $sublink = html_a(web_root()."domain.php",_("[Return to Domain List]"));
        $div->add(_("Domain successfully created!"),html_br());
        $div->add($indlink, $sublink);

        return $div;
    }

//}}}
//{{{   _domains()

    /**
     *  This is a helper method that is used to populate the parent domains listbox
     *
     *  @return Array   $domains  An array of domains indexed by name
     */
    function _domains()
    {
        $domains = array();
        
        $domain = DB_DataObject::Factory('domain');
        $domain->orderBy("name ASC");
        $domain->find();
        /* If we want to be the TLD */
        $domains["none (Parent)"] = 0;
        
        while($domain->fetch())
            $domains[$domain->name] = $domain->id;

        return $domains;
    }

//}}}

}

?>
