<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL$
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Authors: Michael Clay <claym@osuosl.org>                               |
// |          Zack Bartel  <bartel@osuosl.org>                              |
// +------------------------------------------------------------------------+ 
// $Id: workgroup.php 4903 2007-12-17 22:58:31Z morgabra $
            
require_once("includes.php");
require_once(HTCLASS."/datalist/WorkgroupDataList.php");
require_once(FORMDIR."/WorkgroupCreateForm.php");
require_once(HTCLASS."/datalist/ZoneWorkgroupDataList.php");
require_once(FORMDIR."/WorkgroupEditForm.php");
require_once(FORMDIR."/WorkgroupZoneAddForm.php");
require_once(FORMDIR."/WorkgroupBulkDeleteConfirm.php");
require_once(FORMDIR."/MaintainDeleteConfirm.php");
require_once(HTCLASS."/datalist/ObjectOptionDataList.php");

session_start();

setup_user_environment();


$title = html_span("title");

$skin = Skin::Factory($user->color_template);

$content = container();

$zone = $_SESSION['zone'];

switch(strtolower($_REQUEST['action'])) {

case _('delete zones'):
    if(!$user->is_zone_admin($zone))
        header("Location: ".web_root()."denied.php");
    $zwids = $_REQUEST['zwmaps'];
    $wg = $_REQUEST['id'];
    $dcf = new FormProcessor(new WorkgroupBulkDeleteForm($zwids), "delconf");
    $content->add($dcf);
    break;

case 'delconfirm':
    $title->add(_("Deleting Workgroup"));

    if (!$user->is_zone_admin($zone))
        header("Location denied.php");
    
    $dc = new FormProcessor(new MaintainDeleteConfirm("Workgroup", "name"), "workgroupdel");
    $dc->set_render_form_after_success(false);
    $content->add($title, $dc);
    break;

/* This removes the zone_workgroup mapping */
/* TODO: Handle zone_workgroup deletes from ZoneWorkgroupDataList */
case 'confirm_zone_workgroup_del':
    if (!$user->is_zone_admin($zone))
        header("Location: ".web_root()."denied.php");
    $title->add(_("Deleting Zone Workgroup"));

    $zwd = new FormProcessor(new WorkgroupBulkDeleteForm(array($_REQUEST['id'])), "delconf");
    $content->add($title, $zwd);
    break;

case _('toggle default'):
case 'toggle_default':
    if(!$user->is_zone_admin($zone))
        header("Location: ".web_root()."denied.php");

    /* If we got here from the "Action" button in the list then there won't be a zwmap. It will be in zwid */
    if (isset($_REQUEST['zwmaps']))
        $map = $_REQUEST['zwmaps'];
    else
        $map = array($_REQUEST['zwid']);
    
    foreach($map as $zwid) {
        $dbdo = DB_DataObject::Factory('zone_workgroup');
        $dbdo->id = $zwid;//Only one can be default so just take the first one
        $dbdo->find(1);

        $dbdo->is_default = ($dbdo->is_default == 1 ? 0 : 1); //toggle the status
        if($dbdo->update() !== false)
            $dbdo->write_history(_("New Default Workgroup For Zone"), ACTION_MODIFY,
                                $user->username, $dbdo->zone);
        
        //There can be only one default, so set others to not be it
        if($dbdo->is_default == 1) {
            $zw = DB_DataObject::Factory('zone_workgroup');
            $zw->is_default = 0;
            $zw->whereAdd("workgroup!='$dbdo->workgroup'");
            $zw->whereAdd("zone='$dbdo->zone'");
            $zw->update(DB_DATAOBJECT_WHEREADD_ONLY);
        }
    }

case 'edit':
    if(!$user->is_zone_admin($zone))
        header('Location: '.web_root()."denied.php");
    
    $wef = new FormProcessor(new WorkgroupEditForm, "wgedit");
    $zwdl = new ZoneWorkgroupDataList(_("Zones for this Workgroup"));
    $zwdl->user_setup();
    if($user->is_admin())
        $wzaf = new FormProcessor(new WorkgroupZoneAddForm,"wgzoneadd");
    $title->add(_("Modifying Workgroup"));
    $content->add($title);

    //Add the DHCP Options link
    $skin = Skin::Factory($user->color_template);
    $am = $skin->getActionMenu();
    $am->add(html_a("option.php?action=show&amp;object_type=workgroup&amp;object_id={$_REQUEST['id']}", _("View DHCP Options for this Workgroup")));
    $content->add(html_br(2), $am, html_br());

    $content->add(html_br(2), html_span("displayobject_title", _("Update a Workgroup")), $wef, html_br(2));
    $content->add(html_span("displayobject_title", _("Workgroup to Zone Mappings")),$zwdl, html_br(2));
    if($user->is_admin())
        $content->add(html_span("displayobject_title", _("Add this Workgroup to a Zone")), $wzaf, html_br(2));
    break;

case 'create':
    if(!$user->is_zone_admin($zone))
        header("Location: denied.php");
    $title->add(_("Creating Workgroup"));
    $wcf = new FormProcessor(new WorkgroupCreateForm(), "wgcreate");
    $wcf->set_render_form_after_success(false);
    $content->add($title, $wcf);
    break;

case 'show':
case 'show_admin':

default:
   
    $title->add(_("Showing Workgroups"));
    $content->add($title,html_br(2));
   
    /* Action Menu */
    $am =& $skin->getActionMenu();
    if ($user->is_zone_admin($zone))  {
        $create_link = html_a($_SERVER["SCRIPT_NAME"]."?action=create", _("Create Workgroup"));
        $am->add($create_link);
    }
    if(isset($_REQUEST['id'])) {
        $workgroup = new Workgroup($_REQUEST['id']);
        $list = html_a($_SERVER["SCRIPT_NAME"]."?action=show", _("Show Workgroup List"));
        $am->add(html_a($_SERVER['SCRIPT_NAME']."?action=edit&amp;id=".$_REQUEST['id'], _("Edit Workgroup")));
        //$am->add(html_a($_SERVER['SCRIPT_NAME']."?action=showoptions&amp;id=".$_REQUEST['id'], _("View DHCP Options for this Workgroup")));
    $am->add(html_a("option.php?action=show&amp;object_type=workgroup&amp;object_id=".$_REQUEST['id'], _("View DHCP Options for this Workgroup")));
        $am->add($list);
        $content->add(html_br(1), $am, html_br(2));
        $content = Module::apply_filter("object_info",$content,$workgroup); 
    }
    else {
        $wl = new WorkgroupDataList("Workgroups");
        $wl->user_setup();
        $content->add($wl);
    }

}

print $skin->display($content);

?>
