<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Josh Schonstal <schonstal@osuosl.org>                       |
// +------------------------------------------------------------------------+
// $Id:$

/**
  * maintain_displayobj.php - contains the {@link Maintain_Action} class
  *
  * @author $Author:$
  * @filesource
  * @package    modules
  * @subpackage maintain_action
  */

require_once MODDIR.'/core_module.php';

/**
  * This is the 'Maintain_Action' module for Maintain, 
  * which fills in the action bar in datalists
  *
  * @package    modules
  * @subpackage maintain_action
  */
class Maintain_Action extends Core_Module {

/* Overridden Module Methods */
// {{{ _install()

    /**
     *  This method takes care of operations that need to be carried out when the
     *  module is installed.
     *
     *  @return Boolean true
     */
     
    function _install()
    {
        return true;
    }

// }}}
// {{{ _uninstall()

    /**
     *  This method takes care of operations that need to be carried out when the
     *  module is uninstalled.
     *
     *  @return Boolean true
     */
     
    function _uninstall()
    {
        return true;
    }

// }}}
// {{{ register_hooks() (register methods to Maintain module hooks)

/**
  * Connect this module to the module hooks it should reply to
  *
  * @access public
  * @return void
  */
  
    function register_hooks()
    {
        Module::add_filter('action_module', 'display_action', 10);
    }
    
// }}}
// {{{ display_action()

/**
  * Displays the action links.
  *
  * @access public
  * @return string alinks
  */

  function display_action($obj, $row_data, $type)
  {

    //to find out if we're an admin.
    global $user;

    //it should show up as blank if there are no default links

    //generic edit link
    $edit = html_a(web_root()."$type.php?action=edit&amp;id=".$row_data['id'],
        _("Edit"));
    //generic delete links
    $del = html_a(web_root()."$type.php?action=delconfirm&amp;id=".$row_data['id'],
        _("Delete"));
   
    switch($type)
    {
        //vlan, nameserver and SOA have the base actions
        case 'vlan':
        case 'ns':
        case 'soa':
        case 'cname':
        case 'mx':
        case 'option':
            $obj->add(container($edit, "|", $del));
            break;
            
        //dhcp, ip, domain and host all have an enable/disable action link    
        case 'dhcp':
        case 'ip':
        case 'domain':
        case 'host':
        case 'pointer':
            $state = html_a(web_root()."$type.php?action="
                .($row_data['enabled'] ? 'disable' : 'enable').'&amp;id='.$row_data['id'], 
                $row_data['enabled'] ? _("Disable") : _("Enable"));  
                
            $obj->add(container($edit, "|", $del, "|", $state));            
            break;
        
        //workgroups and subnets have options
        case 'workgroup':
        case 'subnet':
            $options = html_a(web_root()."option.php?action=show&amp;object_type=".$type
                ."&amp;object_id=".$row_data['id'], 
                _("Options"));
                
            $obj->add(container($edit, "|", $del, "|", $options));
            break;
        
        case 'zone':
            $merge = html_a(web_root()."$type.php?action=merge&amp;id=".$row_data['id'], 
                _("Merge"));
                
            $obj->add(container($edit, "|", $del, "|", $merge));
            break;
       
        //user is a strange case
        case 'user':
            global $user;
            if($user->username == $row_data['username']) {
                $obj->add(_("(no self-deletion)"));
            } else {
                $obj->add(container(html_a(web_root().$type.".php?action=delete&amp;username="
                .$row_data['username'],_("Delete User"))));
            }
                
            $obj->add(container("|",
            html_a(web_root().$type.".php?action=edit&amp;username=".$row_data['username'],
            _("Edit"))));      
        break;
        
        //another annoying special case >:(
        case 'help':
            $edit = html_a(web_root()."$type.php?action=edit&amp;ident=".$row_data['ident'],
                    _("Edit"));
            $del = html_a(web_root()."$type.php?action=delconfirm&amp;id=".$row_data['ident'],
                    _("Delete"));
            $view = html_a(web_root()."$type.php?action=show&amp;ident=".$row_data['ident'],
                    _("View"));
            if ($user->is_admin()) {
                $obj->add(container($edit,"|",$del,"|",$view));
            } else {
                $obj->add(container($view));
            }
            break;

        //special case >_< (this one really breaks the schema -- they're both the same, too)
        case 'zonerange':
            $del = html_a(web_root()."zone.php?action=delete_ranges&amp;zrid=".$row_data['id'],
                    _("Delete"));
            $endis = html_a(web_root()."zone.php?action=zone_range_endis&amp;id="
            .$_REQUEST['id']."&amp;zrid=".$row_data['id'],
            $row_data['enabled'] ? _("Disable") : _("Enable"));

            $obj->add(container($del, "|", $endis));
            break;

        //YASC
        case 'zonewg':
            $del = html_a(web_root()
                ."workgroup.php?action=confirm_zone_workgroup_del&amp;id=".$row_data['id'],
                _("Delete"));
            
            $tog = html_a(web_root()
                ."workgroup.php?action=toggle_default&amp;id=".$row_data['workgroup']
                ."&amp;zwid=".$row_data['id'],
                $row_data['is_default'] ? _("Remove Default") : _("Make Default"));

            $obj->add(container($del, "|", $tog));
            break;

        //range has a special set of actions
        case 'range':
            $edit = html_a(web_root()."$type.php?action=edit&amp;id=".$row_data['range'],
                _("Edit"));
    
            $del = html_a(web_root()."$type.php?action=delconfirm&amp;id=".$row_data['range'],
                _("Delete"));

            $merge = html_a(web_root()."$type.php?action=merge&amp;id=".$row_data['range'], 
                _("Merge"));
            
            $split = html_a(web_root()."$type.php?action=split&amp;id=".$row_data['range'],
                _("Split"));
                
            $avail = html_a(web_root()."$type.php?action=avail&amp;id=".$row_data['range'],
                _("View Available IPs"));
                
            $obj->add(container($edit, "|", $split, "|", $merge, "|", $del, "|", $avail));
            break;

        default:
    } 
    return $obj;
  }
// }}}

}

?>
